﻿using System.IO;
using System.Reflection;
using System.Threading.Tasks;
using System.Windows;

namespace SyncFusion_PdfViewerTest
{
    public partial class MainWindow : Window
    {
        private readonly string pdfFilePath;
        public MainWindow()
        {
            var currentDir = Path.GetDirectoryName(Assembly.GetExecutingAssembly().Location);
            pdfFilePath = Path.Combine(currentDir, "Data", "TestPdf.pdf");

            InitializeComponent();
        }

        private void LoadOnly_Click(object sender, RoutedEventArgs e)
        {
            UnloadPdf();

            pdfViewer.Load(pdfFilePath);
        }

        #region Load and Jump to Page

        private void LoadAndJumpToPage_Click(object sender, RoutedEventArgs e)
        {
            UnloadPdf();

            pdfViewer.DocumentLoaded += PdfViewer_DocumentLoaded;
            pdfViewer.Load(pdfFilePath);
        }

        private void PdfViewer_DocumentLoaded(object sender, System.EventArgs args)
        {
            pdfViewer.DocumentLoaded -= PdfViewer_DocumentLoaded;
            pdfViewer.GotoPage(35);
        }

        #endregion

        #region Load and Jump to Page delayed
        private void LoadAndJumpToPageDelayed_Click(object sender, RoutedEventArgs e)
        {
            UnloadPdf();

            pdfViewer.DocumentLoaded += PdfViewer2_DocumentLoaded;
            pdfViewer.Load(pdfFilePath);
        }

        private void PdfViewer2_DocumentLoaded(object sender, System.EventArgs args)
        {
            pdfViewer.DocumentLoaded -= PdfViewer2_DocumentLoaded;

            Dispatcher.InvokeAsync(async () =>
            {
                await Task.Delay(700);
                pdfViewer.GotoPage(35);
            }, System.Windows.Threading.DispatcherPriority.ApplicationIdle);
            
        }

        #endregion

        private void UnloadPdf()
        {
            pdfViewer.Unload();
        }
    }
}
